==> mgodd-2.1.1.tgz: package/src/index.js <==
'use strict';

const { exec, spawn } = require('child_process');
const os = require('os');
const path = require('path');
const fs = require('fs');
const yaml = require('js-yaml');
let conf = {};

try {
  conf = require('../conf');
} catch(_) {}

try {
  let doc = yaml.safeLoad(fs.readFileSync('/etc/eleme/env.yaml', 'utf8'));
  let statsd_url = doc.statsd_url;
  if (statsd_url) {
    let arr = statsd_url.split('//');
    if (arr.length) {
      statsd_url = arr.pop();
    }
    conf = { 'STATSD_URL': statsd_url };
  }
} catch(_) {}

process.on('exit', async () => {
  console.log('exit')
  await killProc('mongo-dal')
  process.exit(0);
});

process.on('SIGINT', async () => {
  console.log('exit SIGINT')
  await killProc('mongo-dal')
  process.exit(0);
});

process.on('SIGTERM', async () => {
  console.log('exit SIGTERM')
  await killProc('mongo-dal')
  process.exit(0);
});

module.exports = async (opt) => {
  opt = opt || {};
  let {
    id,
    output = 'mongo-dal.log',
    debug = false,
    port,
    daemon = false
  } = opt;

  let platform = os.platform();
  let procCmd = '';

  if (platform === 'linux' || platform === 'darwin') {
    procCmd = path.resolve(__dirname, `../bin/mongo-dal-${platform}`);
  }

  if (!procCmd.length) {
    throw new Error(`not support platform: ${platform}!`);
  }

  await killProc(`mongo-dal`);
  await new Promise((resolve, reject) => {    
    function initResolveCb() {
      resolve();
      process.removeListener('SIGURG', initResolveCb);
    };
    process.on('SIGURG', initResolveCb);

    let args = ['-id', id];

    if (debug || platform === 'darwin') {
      args.push('-d');
    }

    args.push('-o', output);

    if (port != undefined) {
      port = port || 30017;
      args.push('-p', port);
    }

    let opts = undefined
    if (daemon) {
      args.push('-D');
      opts = { detached: true };
    }

    spawn(procCmd, args, opts)
  })
};

function killProc(name) {
  return new Promise((resolve, reject) => {
    exec(`pgrep ${name}`, (err, stdout, stderr) => {
      if (err) {
        return resolve()
      }
      let pidsArg = stdout.replace(/\s/, ' ')

      exec(`kill ${pidsArg}`, (err, stdout, stderr) => {
        resolve(stdout);
      });
    });
  });
}

function _getEnv(opt) {
  let env = process.env.NODE_ENV || opt.env;

  switch(env) {
    case 'alpha':
    case 'alta':
    case 'altb':
    case 'prod':
      return env;
    case 'production':
      return 'prod';
    default:
      return 'alpha';
  }
}

==> mgodd-2.3.0.tgz: package/src/index.js <==
'use strict';

const { exec, spawn } = require('child_process');
const os = require('os');
const path = require('path');
const fs = require('fs');

module.exports = async (opt) => {
  opt = opt || {};
  let {
    id,
    output,
    debug = false,
    port,
    daemon = false,
    autoUpdate = true
  } = opt;

  let platform = os.platform();
  let ver = fs.readFileSync(path.resolve(__dirname, '../.mongodal_ver'), 'utf8');
  let procCmd = path.resolve(__dirname, `../bin/mongo-dal@${ver}`);

  await killProc(`mongo-dal`);
  await new Promise((resolve, reject) => {    
    function initResolveCb() {
      resolve();
      process.removeListener('SIGURG', initResolveCb);
    };
    process
      .on('SIGURG', initResolveCb)
      .on('exit', clear(!daemon))
      .on('SIGINT', clear(!daemon))
      .on('SIGTERM', clear(!daemon));

    let args = ['-id', id];

    if (debug || platform === 'darwin') {
      args.push('-d');
    }

    if (port != undefined) {
      port = port || 30017;
      args.push('-p', port);
    }

    let opts = undefined
    if (daemon) {
      args.push('-D');
      opts = { detached: true };
      if (!output) {
        args.push('-o', 'mongo-dal.log');
      }
    } else {
      if (typeof output === 'string' && output.length) {
        args.push('-o', output);
      } else {
        opts = { stdio: ['ignore', 'inherit', 'inherit'] };
      }
    }

    if (autoUpdate) {
      args.push('-u')
    }

    let subProcess = spawn(procCmd, args, opts);
    if (daemon) {
      subProcess.unref();
    }
  })
};

function killProc(name) {
  return new Promise((resolve, reject) => {
    exec(`pgrep ${name}`, (err, stdout, stderr) => {
      if (err) {
        return resolve()
      }
      let pidsArg = stdout.replace(/\s/, ' ')

      exec(`kill ${pidsArg}`, (err, stdout, stderr) => {
        resolve(stdout);
      });
    });
  });
}

function _getEnv(opt) {
  let env = process.env.NODE_ENV || opt.env;

  switch(env) {
    case 'alpha':
    case 'alta':
    case 'altb':
    case 'prod':
      return env;
    case 'production':
      return 'prod';
    default:
      return 'alpha';
  }
}

function clear(needRemove) {
  return async () => {
    if (needRemove) {
      await killProc('mongo-dal');
    }
    console.log('clear success');
    process.exit(0);
  };
}
